@@ -76,7 +76,7 @@ if (Sys.info()["sysname"] != "Windows") {
   testthat::test_that(
     "Test a path external to ref_path (in Linux)", {
       testthat::expect_warning(
-        test_path <- abs2rel("~", ref_path),
+        test_path <- abs2rel(normalize_path("~"), ref_path),
         regexp = gsub(
           " ", "[ \n]",
           "do not have a common parent directory"
